<?php
/** @var App\Models\Note $note */
?>
@extends ('layouts.patient')

@section('inner-content')

    <?php
    $hasBills = false;
    if($note->bills->count()) {
        foreach ($note->bills as $bill) {
            if(!$bill->is_cancelled) {
                $hasBills = true;
                break;
            }
        }
    }
    ?>

    <div class="pt-2 pb-3 d-flex align-items-start">
        <h6 class="my-0 text-secondary d-flex align-items-start w-100">
            <a href="/patients/view/{{ $patient->uid }}/notes" class="small text-decoration-none mr-3">
                <i class="fa fa-chevron-left"></i>
            </a>
            <div class="mr-auto">
                <span class="text-dark font-weight-bold">Note
                    <span class="text-secondary font-weight-normal">{{ $note->is_cancelled ? '(CANCELLED)' : '' }}</span>
                </span>
            </div>
            @if($patient->has_mcp_done_onboarding_visit !== 'YES')
                <div class="ml-auto">
                    <div moe relative>
                        <a start show class="font-weight-bold">Mark as Onboarding Visit Note</a>
                        <form url="/api/client/updateMcpOnboardingVisitInfo" class="mcp-theme-1" right>
                            <input type="hidden" name="uid" value="{{$patient->uid}}">
                            <input type="hidden" name="mcpOnboardingVisitNoteUid" value="{{$note->uid}}">
                            <input type="hidden" name="hasMcpDoneOnboardingVisit" value="YES">
                            <input type="hidden" name="mcpOnboardingVisitDate" value="{{$note->effective_dateest}}">
                            <p class="min-width-200px">Mark this patient's onboarding as completed using this note?</p>
                            <div>
                                <button submit class="btn btn-sm btn-success mr-1">Yes</button>
                                <button cancel class="btn btn-sm btn-default border">No</button>
                            </div>
                        </form>
                    </div>

                </div>
            @endif
        </h6>
    </div>

    <div class="card mb-0 {{ $note->is_cancelled ? 'cancelled-item' : '' }}">
        <div class="card-header d-flex align-items-start px-3 border-bottom-0">
            <div class="pr-2">
                {{$note->title}}
                @if(!$note->is_signed_by_hcp)
                <div moe>
                    <a href="" show start><i class="fa fa-edit"></i></a>
                    <form url="/api/note/putTitle">
                        <input type="hidden" name="uid" value="{{$note->uid}}">
                        <div class="mb-2">
                            <input type="text" name="title" value="{{$note->title}}" class="form-control form-control-sm"
                                   placeholder="Title">
                        </div>
                        <div class="form-group mb-0">
                            <button class="btn btn-primary btn-sm" submit>Submit</button>
                            <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                        </div>
                    </form>
                </div>
                @endif
            </div>
            <div class="px-2 border-left border-right">
                <div class="d-flex">
                    <span class="mr-2">{{friendly_date_time($note->effective_dateest, false)}}</span>
                    @if(!$note->is_signed_by_hcp)
                    <span moe class="ml-auto">
                        <a href="" show start><i class="fa fa-calendar"></i></a>
                        <form url="/api/note/putEffectiveDateEST">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <label for="" class="text-secondary text-sm">Effective date EST</label>
                                <input type="date" name="effectiveDateEST" value="{{$note->effective_dateest}}" class="form-control form-control-sm">
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </span>
                    @endif
                </div>
                <div class="d-flex">
                    <span class="mr-2">{{friendly_time($note->effective_time)}}</span>
                    @if(!$note->is_signed_by_hcp)
                    <span moe class="ml-auto">
                        <a href="" show start><i class="fa fa-clock"></i></a>
                        <form url="/api/note/putEffectiveTime">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <label for="" class="text-secondary text-sm">Effective time </label>
                                <input type="time" name="effectiveTime" value="{{ date("H:i", strtotime($note->effective_time)) }}" class="form-control form-control-sm">
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </span>
                    @endif
                </div>
            </div>

            <div class="px-2">
                <div class="d-flex">
                    <span class="mr-2"><span class="text-secondary">HCP:</span> {{$note->hcpPro->name_display}}</span>
                    @if(!$note->is_signed_by_hcp)
                    <div moe class="ml-auto">
                        <a href="" show start><i class="fa fa-edit"></i></a>
                        <form url="/api/note/putHcp">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <select name="hcpProUid" class="form-control form-control-sm">
                                    <option value="">-- Select HCP Pro --</option>
                                    @foreach ($pros as $iPro)
                                        <option value="{{$iPro->uid}}" {{ $note->hcpPro && $iPro->id === $note->hcpPro->id ? 'selected' : '' }}>{{$iPro->name_display}}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </div>
                    @endif
                </div>
                {{--<div class="d-flex">
                    <span class="mr-2"><span class="text-secondary">Ally:</span> {{$note->allyPro ? $note->allyPro->name_display : '-'}}</span>
                    <div moe class="ml-auto">
                        <a href="" show start><i class="fa fa-edit"></i></a>
                        <form url="/api/note/putAlly">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <select name="allyProUid" class="form-control form-control-sm">
                                    <option value="">-- Select Ally Pro --</option>
                                    @foreach ($pros as $iPro)
                                        <option value="{{$iPro->uid}}" {{ $note->allyPro && $iPro->id === $note->allyPro->id ? 'selected' : '' }}>{{$iPro->name_display}}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </div>
                </div>--}}
            </div>
            <div class="ml-auto d-flex align-items-start">
                <div class="pr-2">
                    <div>
                        @if($note->is_signed_by_hcp)
                            <span class="text-secondary">
                        <i class="fa fa-check"></i>
                        HCP Signed
                    </span>
                        @else
                            <div moe
                                 class="{{ $note->hcp_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                 title="{{ $note->hcp_pro_id !== $pro->id ? 'Only the note\'s HCP can sign' : '' }}">
                                <a class="" href="" show start>Sign as HCP</a>
                                <form url="/api/note/signAsHcp">
                                    <input type="hidden" name="uid" value="{{$note->uid}}">
                                    <p>Sign this note as HCP?</p>
                                    <div class="mb-0">
                                        <button class="btn btn-success btn-sm" submit>Sign</button>
                                        <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                    </div>
                                </form>
                            </div>
                        @endif
                    </div>
                    {{--<div>
                        @if($note->is_signed_by_ally)
                            <span class="text-secondary">
                                <i class="fa fa-check"></i>
                                Ally Signed
                            </span>
                        @else
                            <div moe
                                 class="{{ $note->ally_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                 title="{{ $note->ally_pro_id !== $pro->id ? 'Only the note\'s Ally can sign' : '' }}">
                                <a class="" href="" show start>Sign as Ally</a>
                                <form url="/api/note/signAsAlly">
                                    <input type="hidden" name="uid" value="{{$note->uid}}">
                                    <p>Sign this note as Ally?</p>
                                    <div class="mb-0">
                                        <button class="btn btn-success btn-sm" submit>Sign</button>
                                        <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                    </div>
                                </form>
                            </div>
                        @endif
                    </div>--}}
                </div>
                <div class="pl-2 border-left">
                    @if($patient->has_mcp_done_onboarding_visit === 'YES')
                    <div class="d-flex justify-content-end">
                        <div moe relatve class="">
                            <a class="" href="" show start>Create Bill</a>
                            <form url="/api/bill/createForNote" right>
                                <input type="hidden" name="noteUid" value="{{$note->uid}}">
                                <div class="mb-2">
                                    <label for="" class="text-secondary text-sm">Effective Date</label>
                                    <input type="date" name="effectiveDate" class="form-control form-control-sm" value="{{date('Y-m-d')}}" required>
                                </div>
                                <div class="mb-2">
                                    <select autofocus class="form-control" name="code" value="">
                                        <option value="">-- Select Code --</option>
                                        <?php $noteRates = $pro->noteRates(); ?>
                                        @if($noteRates && count($noteRates))
                                            @foreach($noteRates as $noteRate)
                                                <option value="{{ $noteRate->code }}">{{ $noteRate->code }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason1" placeholder="Reason 1" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason2" placeholder="Reason 2" class="form-control form-control-sm">
                                </div>
                                <div class="">
                                    <button class="btn btn-primary btn-sm" submit>Submit</button>
                                    <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                    </div>
                    @endif
                    <div class="d-flex justify-content-end">
                        @if(!$note->is_cancelled)
                        <div moe relatve
                             class="{{ $hasBills ? 'moe-disabled' : '' }}"
                             title="{{ $hasBills ? 'Cannot cancel note since it has un-cancelled bills in it' : '' }}">
                            <a class="text-danger" href="" show start>Cancel Note</a>
                            <form url="/api/note/cancel" right>
                                <input type="hidden" name="uid" value="{{$note->uid}}">
                                <p class="small mb-2">Are you sure you want to cancel this note?</p>
                                <div class="mb-2">
                                    <textarea name="memo" id="" cols="30" rows="5" placeholder="Memo" class="memo-textarea form-control form-control-sm"></textarea>
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-danger mr-2" submit>Yes</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>No</button>
                                </div>
                            </form>
                        </div>
                        @else
                            <span class="text-secondary font-weight-bold">CANCELLED</span>
                        @endif
                    </div>
                </div>
            </div>
        </div>
        <div class="card-body p-0">
            <div>

                <div class="mb-3">
                    <div>
                        <div class="primary-form">
                            <div class="note-content {{ $note->is_cancelled ? 'cancelled' : '' }} {{ $note->is_signed_by_hcp ? 'readonly' : '' }}"
                                 data-note-uid="{{ $note->uid  }}"
                                 {{ !$note->is_cancelled && empty($note->free_text_html) ? 'auto-edit' : '' }}>{!! $note->free_text_html !!}</div>
                        </div>
                        {{--<div moe class="d-inline">
                            <a show start><i class="fa fa-edit"></i></a>
                            <form url="/api/note/putFreeTextHtml">
                                <input type="hidden" name="uid" value="{{$note->uid}}">
                                <div class="mb-2">
                                    <textarea name="freeTextHtml" id="" cols="30" rows="5"
                                              placeholder="Content"
                                              class="memo-textarea form-control form-control-sm">{!! $note->free_text_html !!}</textarea>
                                </div>
                                <div class="mb-0">
                                    <button class="btn btn-primary btn-sm" submit>Save</button>
                                    <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>--}}
                    </div>
                </div>

                @if($note->bills->count())
                    <div class="mt-2 px-3">
                        <p class="font-weight-bold mb-2 text-secondary">Bills</p>
                        <table class="table table-sm tabe-striped mb-3 border-left border-right border-bottom">
                            <thead class="bg-light">
                            <tr>
                                <th class="border-bottom-0 w-25 pl-3">Code</th>
                                <th class="border-bottom-0 w-25 pl-2">Reason</th>
                                <th class="border-bottom-0 w-25 pl-2">Amount</th>
                                <th class="border-bottom-0"></th>
                            </tr>
                            </thead>
                            <tbody>
                            @foreach ($note->bills as $bill)
                                <tr>
                                    <td class="pl-3 {{ $bill->is_cancelled ? 'text-secondary' : '' }}">{{$bill->code}}</td>
                                    <td class="pl-2">
                                        {{ $bill->reason1 }}
                                        <div class="text-secondary small">{{ $bill->reason2 }}</div>
                                    </td>
                                    <td class="pl-2">
                                        @if($bill->has_hcp_been_paid)
                                            <span class="text-dark">Received:</span><span class="font-weight-bold text-success ml-2">${{ $bill->hcp_payment_amount }}</span>
                                        @else
                                            <span class="text-dark">Expected:</span><span class="font-weight-bold text-dark ml-2">{{ $bill->hcp_expected_payment_amount ? '$' . $bill->hcp_expected_payment_amount : '-' }}</span>
                                        @endif
                                    </td>
                                    <td>
                                        <div class="">
                                            @if(!$bill->is_cancelled)
                                                @if($bill->is_signed_by_hcp)
                                                    <div class="d-block text-secondary">
                                                        <i class="fa fa-check"></i>
                                                        HCP Signed
                                                    </div>
                                                @else
                                                    <div moe
                                                         class="d-block {{ $bill->hcp_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                                         title="{{ $bill->hcp_pro_id !== $pro->id ? 'Only the bill\'s HCP can sign' : '' }}">
                                                        <a class="" href="" show start>Sign as HCP</a>
                                                        <form url="/api/bill/signAsHcp">
                                                            <input type="hidden" name="uid" value="{{$bill->uid}}">
                                                            <p>Sign this bill as HCP?</p>
                                                            <div class="mb-0">
                                                                <button class="btn btn-success btn-sm" submit>Sign</button>
                                                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                                            </div>
                                                        </form>
                                                    </div>
                                                @endif
                                            @endif
                                            @if($bill->is_cancelled)
                                                <div class="d-block text-secondary">
                                                    Cancelled
                                                </div>
                                            @else
                                                <div class="d-block" moe>
                                                    <a class="text-danger" href="" show start>Cancel</a>
                                                    <form url="/api/bill/markCancelled">
                                                        <input type="hidden" name="uid" value="{{$bill->uid}}">
                                                        <p>Cancel this bill?</p>
                                                        <div class="mb-0">
                                                            <button class="btn btn-danger btn-sm" submit>Yes</button>
                                                            <button class="btn btn-default border btn-sm" cancel>No</button>
                                                        </div>
                                                    </form>
                                                </div>
                                            @endif
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                            </tbody>
                        </table>
                    </div>
                @else
                    <div class="my-3 px-3 d-flex">
                        <p class="font-weight-bold mb-0 text-secondary">No bills in this note</p>
                        @if($patient->has_mcp_done_onboarding_visit === 'YES')
                        <span class="mx-2 text-secondary">|</span>
                        <span moe class="">
                            <a class="" href="" show start>Create Bill</a>
                            <form url="/api/bill/createForNote">
                                <input type="hidden" name="noteUid" value="{{$note->uid}}">
                                <div class="mb-2">
                                    <label for="" class="text-secondary text-sm">Effective Date</label>
                                    <input type="date" name="effectiveDate" class="form-control form-control-sm" value="{{date('Y-m-d')}}" required>
                                </div>
                                <div class="mb-2">
                                    <select autofocus class="form-control" name="code" value="">
                                        <option value="">-- Select Code --</option>
                                        <?php $noteRates = $pro->noteRates(); ?>
                                        @if($noteRates && count($noteRates))
                                            @foreach($noteRates as $noteRate)
                                                <option value="{{ $noteRate->code }}">{{ $noteRate->code }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason1" placeholder="Reason 1" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason2" placeholder="Reason 2" class="form-control form-control-sm">
                                </div>
                                <div class="">
                                    <button class="btn btn-primary btn-sm" submit>Submit</button>
                                    <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                </div>
                            </form>
                        </span>
                        @endif
                    </div>
                @endif
            </div>
        </div>
    </div>
@endsection
